==> pythonsol-0.0.3.tar.gz: pythonsol-0.0.3/pythonsol/SysLogger.py <==
"""
# -*- coding: utf-8 -*-
#====================================================================================================================
#
# Copyright (C) 2013 Laurent Champagnac
#
#
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#====================================================================================================================
"""

from logging.handlers import SysLogHandler
import socket

from gevent import GreenletExit

from pythonsol.SolBase import SolBase


class SysLogger(SysLogHandler):
    """
    Sys log handler (will format and emit logs toward rsyslog)
    """

    def __init__(self, address="/dev/log", facility=SysLogHandler.LOG_LOCAL1, socktype=socket.SOCK_DGRAM,
                 logCallback=None):
        """
        Init
        :param address: tuple ('ip', port) or string "target"
        :type address:  str, tuple
        :param facility: log facility
        :type facility: int
        :param socktype: Type of socket
        :type socktype: int
        :param logCallback: Callback for unit test
        """

        # Store
        self._logCallback = logCallback

        # Base call
        SysLogHandler.__init__(self, address, facility, socktype)

    def notifyLog(self, msg):
        """
        Notify log to callback if set (unittest purpose)
        :param msg: Log message
        :type msg: unicode,str
        """
        try:
            if self._logCallback:
                self._logCallback(msg)
        except:
            pass

    def emit(self, record):
        """
        Emit a record.
        :param record: The record to log
        :type record: logging.LogRecord
        """

        # Write
        try:
            # Format
            msg = self.format(record) + '\000'

            # Get component name
            cn = SolBase.getCompoName()

            # We append the machine+component name at the beginning
            if isinstance(msg, unicode):
                msg = u"{0} | {1} | {2}".format(SolBase.getMachineName(), cn, msg)
                msg = msg.encode('utf-8')
            else:
                msg = "{0} | {1} | {2}".format(SolBase.getMachineName(), cn, msg)

            # Add priority + facility (int)
            priority = '<%d>' % self.encodePriority(self.facility, self.mapPriority(record.levelname))
            msg = priority + cn + ": " + msg

            # Notify
            self.notifyLog(msg)

            # Send to socket
            if self.unixsocket:
                try:
                    self.socket.send(msg)
                except socket.error:
                    self._connect_unixsocket(self.address)
                    self.socket.send(msg)
            elif self.socktype == socket.SOCK_DGRAM:
                self.socket.sendto(msg, self.address)
            else:
                self.socket.sendall(msg)
        except GreenletExit:
            pass
        except (KeyboardInterrupt, SystemExit):
            raise
        except:
            self.handleError(record)

==> pythonsol-0.0.4.tar.gz: pythonsol-0.0.4/pythonsol/SysLogger.py <==
"""
# -*- coding: utf-8 -*-
#===============================================================================
#
# Copyright (C) 2013/2014 Laurent Champagnac
#
#
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
#===============================================================================
"""

from logging.handlers import SysLogHandler
import socket

from gevent import GreenletExit

from pythonsol.SolBase import SolBase


class SysLogger(SysLogHandler):
    """
    Sys log handler (will format and emit logs toward rsyslog)
    """

    def __init__(self, address="/dev/log", facility=SysLogHandler.LOG_LOCAL1, socktype=socket.SOCK_DGRAM,
                 logCallback=None):
        """
        Init
        :param address: tuple ('ip', port) or string "target"
        :type address:  str, tuple
        :param facility: log facility
        :type facility: int
        :param socktype: Type of socket
        :type socktype: int
        :param logCallback: Callback for unit test
        """

        # Store
        self._logCallback = logCallback

        # Base call
        SysLogHandler.__init__(self, address, facility, socktype)

    def notifyLog(self, msg):
        """
        Notify log to callback if set (unittest purpose)
        :param msg: Log message
        :type msg: unicode,str
        """
        try:
            if self._logCallback:
                self._logCallback(msg)
        except:
            pass

    def emit(self, record):
        """
        Emit a record.
        :param record: The record to log
        :type record: logging.LogRecord
        """

        # Write
        try:
            # Format
            msg = self.format(record) + '\000'

            # Get component name
            cn = SolBase.getCompoName()

            # We append the machine+component name at the beginning
            if isinstance(msg, unicode):
                msg = u"{0} | {1} | {2}".format(SolBase.getMachineName(), cn, msg)
                msg = msg.encode('utf-8')
            else:
                msg = "{0} | {1} | {2}".format(SolBase.getMachineName(), cn, msg)

            # Add priority + facility (int)
            priority = '<%d>' % self.encodePriority(self.facility, self.mapPriority(record.levelname))
            msg = priority + cn + ": " + msg

            # Notify
            self.notifyLog(msg)

            # Send to socket
            if self.unixsocket:
                try:
                    self.socket.send(msg)
                except socket.error:
                    self._connect_unixsocket(self.address)
                    self.socket.send(msg)
            elif self.socktype == socket.SOCK_DGRAM:
                self.socket.sendto(msg, self.address)
            else:
                self.socket.sendall(msg)
        except GreenletExit:
            pass
        except (KeyboardInterrupt, SystemExit):
            raise
        except:
            self.handleError(record)
